@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2016-2021 The strace developers.
+ * Copyright (c) 2016-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -46,14 +46,15 @@ SYS_FUNC(getxgid)
 SYS_FUNC(osf_statfs)
 {
 	/* pathname */
+	tprints_arg_name("pathname");
 	printpath(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* buf */
+	tprints_arg_next_name("buf");
 	printaddr(tcp->u_arg[1]);
-	tprint_arg_next();
 
 	/* size */
+	tprints_arg_next_name("size");
 	PRINT_VAL_U(tcp->u_arg[2]);
 
 	return RVAL_DECODED;
@@ -62,14 +63,15 @@ SYS_FUNC(osf_statfs)
 SYS_FUNC(osf_fstatfs)
 {
 	/* fd */
+	tprints_arg_name("fd");
 	printfd(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* buf */
+	tprints_arg_next_name("buf");
 	printaddr(tcp->u_arg[1]);
-	tprint_arg_next();
 
 	/* size */
+	tprints_arg_next_name("size");
 	PRINT_VAL_U(tcp->u_arg[2]);
 
 	return RVAL_DECODED;
