@@ -36,6 +36,7 @@ print_bpf_filter_code(const uint16_t code, bool extended)
 	const struct xlat *mode = extended ? ebpf_mode : bpf_mode;
 	uint16_t i = code & ~BPF_CLASS(code);
 
+	tprint_flags_begin();
 	printxval(extended ? ebpf_class : bpf_class, BPF_CLASS(code),
 		  "BPF_???");
 	switch (BPF_CLASS(code)) {
@@ -43,7 +44,7 @@ print_bpf_filter_code(const uint16_t code, bool extended)
 	case BPF_STX:
 		if (!extended) {
 			if (i) {
-				tprint_or();
+				tprint_flags_or();
 				PRINT_VAL_X(i);
 				tprints_comment("BPF_???");
 			}
@@ -53,20 +54,20 @@ print_bpf_filter_code(const uint16_t code, bool extended)
 
 	case BPF_LD:
 	case BPF_LDX:
-		tprint_or();
+		tprint_flags_or();
 		printxvals(BPF_SIZE(code), "BPF_???",
 			   bpf_size, extended ? ebpf_size : NULL, NULL);
-		tprint_or();
+		tprint_flags_or();
 		printxval(mode, BPF_MODE(code), "BPF_???");
 		break;
 
 	case BPF_MISC: /* BPF_ALU64 in eBPF */
 		if (!extended) {
-			tprint_or();
+			tprint_flags_or();
 			printxval(bpf_miscop, BPF_MISCOP(code), "BPF_???");
 			i &= ~BPF_MISCOP(code);
 			if (i) {
-				tprint_or();
+				tprint_flags_or();
 				PRINT_VAL_X(i);
 				tprints_comment("BPF_???");
 			}
@@ -75,37 +76,38 @@ print_bpf_filter_code(const uint16_t code, bool extended)
 		ATTRIBUTE_FALLTHROUGH; /* extended == true */
 
 	case BPF_ALU:
-		tprint_or();
+		tprint_flags_or();
 		printxval(bpf_src, BPF_SRC(code), "BPF_???");
-		tprint_or();
+		tprint_flags_or();
 		printxvals(BPF_OP(code), "BPF_???",
 			   bpf_op_alu,
 			   extended ? ebpf_op_alu : NULL, NULL);
 		break;
 
 	case BPF_JMP:
-		tprint_or();
+		tprint_flags_or();
 		printxval(bpf_src, BPF_SRC(code), "BPF_???");
-		tprint_or();
+		tprint_flags_or();
 		printxvals(BPF_OP(code), "BPF_???",
 			   bpf_op_jmp, extended ? ebpf_op_jmp : NULL, NULL);
 		break;
 
 	case BPF_RET: /* Reserved in eBPF */
 		if (!extended) {
-			tprint_or();
+			tprint_flags_or();
 			printxval(bpf_rval, BPF_RVAL(code), "BPF_???");
 			i &= ~BPF_RVAL(code);
 		}
 
 		if (i) {
-			tprint_or();
+			tprint_flags_or();
 			PRINT_VAL_X(i);
 			tprints_comment("BPF_???");
 		}
 
 		break;
 	}
+	tprint_flags_end();
 }
 
 static void
