@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2023 The strace developers.
+ * Copyright (c) 2014-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,10 +13,11 @@ static void
 decode_chmod(struct tcb *tcp, const int offset)
 {
 	/* pathname */
+	tprints_arg_name("pathname");
 	printpath(tcp, tcp->u_arg[offset]);
-	tprint_arg_next();
 
 	/* mode */
+	tprints_arg_next_name("mode");
 	print_numeric_umode_t(tcp->u_arg[offset + 1]);
 }
 
@@ -31,9 +32,10 @@ static void
 decode_fchmodat(struct tcb *tcp)
 {
 	/* dirfd */
+	tprints_arg_name("dirfd");
 	print_dirfd(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
+	tprint_arg_next();
 	decode_chmod(tcp, 1);
 }
 
@@ -47,8 +49,8 @@ SYS_FUNC(fchmodat)
 SYS_FUNC(fchmodat2)
 {
 	decode_fchmodat(tcp);
-	tprint_arg_next();
 
+	tprints_arg_next_name("flags");
 	printflags(fchmodat_flags, tcp->u_arg[3], "AT_???");
 
 	return RVAL_DECODED;
@@ -57,10 +59,11 @@ SYS_FUNC(fchmodat2)
 SYS_FUNC(fchmod)
 {
 	/* fd */
+	tprints_arg_name("fd");
 	printfd(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* mode */
+	tprints_arg_next_name("mode");
 	print_numeric_umode_t(tcp->u_arg[1]);
 
 	return RVAL_DECODED;
