@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2021 The strace developers.
+ * Copyright (c) 1999-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,14 +10,18 @@
 static int
 dup_123(struct tcb *const tcp, const int newfd_arg, const int flags_arg)
 {
+	/* oldfd */
+	tprints_arg_name("oldfd");
 	printfd(tcp, tcp->u_arg[0]);
 
 	if (newfd_arg > 0) {
-		tprints(", ");
+		/* newfd */
+		tprints_arg_next_name("newfd");
 		printfd(tcp, tcp->u_arg[newfd_arg]);
 
 		if (flags_arg > 0) {
-			tprints(", ");
+			/* flags */
+			tprints_arg_next_name("flags");
 			printflags(open_mode_flags, tcp->u_arg[flags_arg],
 				   "O_???");
 		}
