@@ -18,7 +18,7 @@
 [  8] = { 2,	TD|TF,		SEN(creat),			"creat"			},
 [  9] = { 2,	TF,		SEN(link),			"link"			},
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
-[ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
+[ 11] = { 3,	CC|TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
 [ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
@@ -179,7 +179,7 @@
 [169] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [170] = { 3,	TC,		SEN(setresgid16),		"setresgid"		},
 [171] = { 3,	TC,		SEN(getresgid16),		"getresgid"		},
-[172] = { 5,	TC,		SEN(prctl),			"prctl"			},
+[172] = { 5,	CC|TC,		SEN(prctl),			"prctl"			},
 [173] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [174] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
@@ -398,4 +398,4 @@
 [389] = { 3,	0,		SEN(getrandom),			"getrandom"		},
 [390] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
 [391] = { 3,	TD,		SEN(bpf),			"bpf"			},
-[392] = { 5,	TD|TF|TP|TSD|SE|SI,	SEN(execveat),			"execveat"		},
+[392] = { 5,	CC|TD|TF|TP|TSD|SE|SI,	SEN(execveat),			"execveat"		},
