@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2021 The strace developers.
+ * Copyright (c) 2015-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,7 +13,8 @@ arch_get_scno(struct tcb *tcp)
 
 	if (!scno_in_range(tcp->scno)) {
 		if (mips_REG_A3 == 0 || mips_REG_A3 == (uint64_t) -1) {
-			debug_msg("stray syscall exit: v0 = %ld", tcp->scno);
+			debug_msg("stray syscall exit: v0 = %#llx",
+				  (unsigned long long) tcp->scno);
 			return 0;
 		}
 	}
