@@ -20,7 +20,7 @@
 [  8] = { 2,	TD|TF,		SEN(creat),			"creat"			},
 [  9] = { 2,	TF,		SEN(link),			"link"			},
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
-[ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
+[ 11] = { 3,	CC|TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
 [ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
@@ -181,7 +181,7 @@
 [169] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [170] = { 3,	TC,		SEN(setresgid16),		"setresgid"		},
 [171] = { 3,	TC,		SEN(getresgid16),		"getresgid"		},
-[172] = { 5,	TC,		SEN(prctl),			"prctl"			},
+[172] = { 5,	CC|TC,		SEN(prctl),			"prctl"			},
 [173] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [174] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
@@ -382,7 +382,7 @@
 [373] = { 3,	0,		SEN(getrandom),			"getrandom"		},
 [374] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
 [375] = { 3,	TD,		SEN(bpf),			"bpf"			},
-[376] = { 5,	TD|TF|TP|TSD|SE|SI,	SEN(execveat),			"execveat"		},
+[376] = { 5,	CC|TD|TF|TP|TSD|SE|SI,	SEN(execveat),			"execveat"		},
 [377] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
 [378] = { 3,	0,		SEN(membarrier),		"membarrier"		},
 [379] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
