@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 The strace developers.
+ * Copyright (c) 2014-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -18,24 +18,24 @@ SYS_FUNC(reboot)
 	const unsigned int cmd = tcp->u_arg[2];
 
 	/* magic */
-	printxval(bootflags1, magic1, "LINUX_REBOOT_MAGIC_???");
-	tprint_arg_next();
+	tprints_arg_name("magic");
+	printxval(bootflags1, magic1, "LINUX_REBOOT_MAGIC1???");
 
 	/* magic2 */
-	printxval(bootflags2, magic2, "LINUX_REBOOT_MAGIC_???");
-	tprint_arg_next();
+	tprints_arg_next_name("magic2");
+	printxval(bootflags2, magic2, "LINUX_REBOOT_MAGIC2???");
 
 	/* cmd */
+	tprints_arg_next_name("op");
 	printxval(bootflags3, cmd, "LINUX_REBOOT_CMD_???");
 	if (cmd == LINUX_REBOOT_CMD_RESTART2) {
-		tprint_arg_next();
-
 		/*
 		 * The size of kernel buffer is 256 bytes and
 		 * the last byte is always zero, at most 255 bytes
 		 * are copied from the user space.
 		 */
 		/* arg */
+		tprints_arg_next_name("arg");
 		printstr_ex(tcp, tcp->u_arg[3], 255, QUOTE_0_TERMINATED);
 	}
 	return RVAL_DECODED;
