@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020-2022 The strace developers.
+ * Copyright (c) 2020-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,22 +8,9 @@
 #include "defs.h"
 #include <linux/tee.h>
 
-/* Not in UAPI.  */
-struct tee_ioctl_shm_register_fd_data {
-	int64_t fd;
-	uint64_t size;
-	uint32_t flags;
-	uint8_t _pad1[4];
-	int32_t id;
-	uint8_t _pad2[4];
-} ATTRIBUTE_ALIGNED(8);
-
-#define TEE_IOC_SHM_REGISTER_FD _IOWR(0xa4, 8, struct tee_ioctl_shm_register_fd_data)
-
 #include "xlat/tee_ioctl_gen_caps.h"
 #include "xlat/tee_ioctl_impl_ids.h"
 #include "xlat/tee_ioctl_login_types.h"
-#include "xlat/tee_ioctl_max_arg_size.h"
 #include "xlat/tee_ioctl_origins.h"
 #include "xlat/tee_ioctl_optee_caps.h"
 #include "xlat/tee_ioctl_param_attr_types.h"
@@ -129,6 +116,28 @@ tee_print_param_fn(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data
 		PRINT_VAL_U(param->c);
 		break;
 
+	case TEE_IOCTL_PARAM_ATTR_TYPE_UBUF_INPUT:
+	case TEE_IOCTL_PARAM_ATTR_TYPE_UBUF_INOUT:
+	case TEE_IOCTL_PARAM_ATTR_TYPE_UBUF_OUTPUT:
+		tprint_struct_next();
+		tprints_field_name("buf");
+		PRINT_VAL_X(param->a);
+		tprint_struct_next();
+		tprints_field_name("size");
+		PRINT_VAL_X(param->b);
+		break;
+
+	case TEE_IOCTL_PARAM_ATTR_TYPE_OBJREF_INPUT:
+	case TEE_IOCTL_PARAM_ATTR_TYPE_OBJREF_INOUT:
+	case TEE_IOCTL_PARAM_ATTR_TYPE_OBJREF_OUTPUT:
+		tprint_struct_next();
+		tprints_field_name("obj_id");
+		PRINT_VAL_X(param->a);
+		tprint_struct_next();
+		tprints_field_name("flags");
+		PRINT_VAL_X(param->b);
+		break;
+
 	case TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT:
 	case TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT:
 	case TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT:
@@ -161,11 +170,10 @@ tee_version(struct tcb *const tcp, const kernel_ulong_t arg)
 {
 	struct tee_ioctl_version_data version;
 
-	if (entering(tcp)) {
-		tprint_arg_next();
+	if (entering(tcp))
 		return 0;
-	}
 
+	tprints_arg_next_name("argp");
 	if (umove_or_printaddr(tcp, arg, &version))
 		return RVAL_IOCTL_DECODED;
 
@@ -198,7 +206,7 @@ tee_open_session(struct tcb *const tcp, const kernel_ulong_t arg)
 	gid_t gid;
 
 	if (entering(tcp)) {
-		tprint_arg_next();
+		tprints_arg_next_name("argp");
 
 		if ((rval = TEE_FETCH_BUF_DATA(buf_data, open_session, &params)))
 			return rval;
@@ -284,7 +292,7 @@ tee_invoke(struct tcb *const tcp, const kernel_ulong_t arg)
 	uint64_t params;
 
 	if (entering(tcp)) {
-		tprint_arg_next();
+		tprints_arg_next_name("argp");
 		if ((rval = TEE_FETCH_BUF_DATA(buf_data, invoke, &params)))
 			return rval;
 
@@ -332,7 +340,7 @@ tee_cancel(struct tcb *const tcp, const kernel_ulong_t arg)
 {
 	struct tee_ioctl_cancel_arg cancel;
 
-	tprint_arg_next();
+	tprints_arg_next_name("argp");
 	if (umove_or_printaddr(tcp, arg, &cancel))
 		return RVAL_IOCTL_DECODED;
 
@@ -350,7 +358,7 @@ tee_close_session(struct tcb *const tcp, const kernel_ulong_t arg)
 {
 	struct tee_ioctl_close_session_arg close_session;
 
-	tprint_arg_next();
+	tprints_arg_next_name("argp");
 	if (umove_or_printaddr(tcp, arg, &close_session))
 		return RVAL_IOCTL_DECODED;
 
@@ -370,7 +378,7 @@ tee_suppl_recv(struct tcb *const tcp, const kernel_ulong_t arg)
 	uint64_t params;
 
 	if (entering(tcp)) {
-		tprint_arg_next();
+		tprints_arg_next_name("argp");
 		if ((rval = TEE_FETCH_BUF_DATA(buf_data, supp_recv, &params)))
 			return rval;
 
@@ -416,7 +424,7 @@ tee_suppl_send(struct tcb *const tcp, const kernel_ulong_t arg)
 	uint64_t params;
 
 	if (entering(tcp)) {
-		tprint_arg_next();
+		tprints_arg_next_name("argp");
 		if ((rval = TEE_FETCH_BUF_DATA(buf_data, supp_send, &params)))
 			return rval;
 
@@ -456,7 +464,7 @@ tee_shm_alloc(struct tcb *const tcp, const kernel_ulong_t arg)
 	struct tee_ioctl_shm_alloc_data shm_alloc;
 
 	if (entering(tcp)) {
-		tprint_arg_next();
+		tprints_arg_next_name("argp");
 		if (umove_or_printaddr(tcp, arg, &shm_alloc))
 			return RVAL_IOCTL_DECODED;
 
@@ -495,7 +503,7 @@ tee_shm_register_fd(struct tcb *const tcp, const kernel_ulong_t arg)
 	struct tee_ioctl_shm_register_fd_data shm_register_fd;
 
 	if (entering(tcp)) {
-		tprint_arg_next();
+		tprints_arg_next_name("argp");
 		if (umove_or_printaddr(tcp, arg, &shm_register_fd))
 			return RVAL_IOCTL_DECODED;
 
@@ -531,7 +539,7 @@ tee_shm_register(struct tcb *const tcp, const kernel_ulong_t arg)
 	struct tee_ioctl_shm_register_data shm_register;
 
 	if (entering(tcp)) {
-		tprint_arg_next();
+		tprints_arg_next_name("argp");
 		if (umove_or_printaddr(tcp, arg, &shm_register))
 			return RVAL_IOCTL_DECODED;
 
