@@ -35,18 +35,19 @@ static int
 decode_setxattr_without_path(struct tcb *const tcp)
 {
 	/* name */
+	tprints_arg_next_name("name");
 	printstr(tcp, tcp->u_arg[1]);
-	tprint_arg_next();
 
 	/* value */
+	tprints_arg_next_name("value");
 	print_xattr_val(tcp, tcp->u_arg[2], tcp->u_arg[3]);
-	tprint_arg_next();
 
 	/* size */
+	tprints_arg_next_name("size");
 	PRINT_VAL_U(tcp->u_arg[3]);
-	tprint_arg_next();
 
 	/* flags */
+	tprints_arg_next_name("flags");
 	printflags(xattrflags, tcp->u_arg[4], "XATTR_???");
 
 	return RVAL_DECODED;
@@ -55,8 +56,8 @@ decode_setxattr_without_path(struct tcb *const tcp)
 SYS_FUNC(setxattr)
 {
 	/* pathname */
+	tprints_arg_name("pathname");
 	printpath(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
 	return decode_setxattr_without_path(tcp);
 }
@@ -64,8 +65,8 @@ SYS_FUNC(setxattr)
 SYS_FUNC(fsetxattr)
 {
 	/* fd */
+	tprints_arg_name("fd");
 	printfd(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
 	return decode_setxattr_without_path(tcp);
 }
@@ -75,24 +76,26 @@ decode_getxattr_without_path(struct tcb *const tcp)
 {
 	if (entering(tcp)) {
 		/* name */
+		tprints_arg_next_name("name");
 		printstr(tcp, tcp->u_arg[1]);
-		tprint_arg_next();
 
 		if (tcp->u_arg[3])
 			return 0;
 
 		/* value */
+		tprints_arg_next_name("value");
 		printaddr(tcp->u_arg[2]);
-		tprint_arg_next();
 
 		/* size */
+		tprints_arg_next_name("size");
 		PRINT_VAL_U(tcp->u_arg[3]);
 	} else {
 		/* value */
+		tprints_arg_next_name("value");
 		print_xattr_val(tcp, tcp->u_arg[2], tcp->u_rval);
-		tprint_arg_next();
 
 		/* size */
+		tprints_arg_next_name("size");
 		PRINT_VAL_U(tcp->u_arg[3]);
 	}
 
@@ -103,8 +106,8 @@ SYS_FUNC(getxattr)
 {
 	if (entering(tcp)) {
 		/* pathname */
+		tprints_arg_name("pathname");
 		printpath(tcp, tcp->u_arg[0]);
-		tprint_arg_next();
 	}
 
 	return decode_getxattr_without_path(tcp);
@@ -114,8 +117,8 @@ SYS_FUNC(fgetxattr)
 {
 	if (entering(tcp)) {
 		/* fd */
+		tprints_arg_name("fd");
 		printfd(tcp, tcp->u_arg[0]);
-		tprint_arg_next();
 	}
 
 	return decode_getxattr_without_path(tcp);
@@ -126,14 +129,15 @@ print_xattr_list(struct tcb *const tcp, const kernel_ulong_t addr,
 		 const kernel_ulong_t size)
 {
 	/* list */
+	tprints_arg_next_name("list");
 	if (!size || syserror(tcp)) {
 		printaddr(addr);
 	} else {
 		printstrn(tcp, addr, tcp->u_rval);
 	}
-	tprint_arg_next();
 
 	/* size */
+	tprints_arg_next_name("size");
 	PRINT_VAL_U(size);
 }
 
@@ -141,8 +145,8 @@ SYS_FUNC(listxattr)
 {
 	if (entering(tcp)) {
 		/* pathname */
+		tprints_arg_name("pathname");
 		printpath(tcp, tcp->u_arg[0]);
-		tprint_arg_next();
 	} else {
 		print_xattr_list(tcp, tcp->u_arg[1], tcp->u_arg[2]);
 	}
@@ -153,8 +157,8 @@ SYS_FUNC(flistxattr)
 {
 	if (entering(tcp)) {
 		/* fd */
+		tprints_arg_name("fd");
 		printfd(tcp, tcp->u_arg[0]);
-		tprint_arg_next();
 	} else {
 		print_xattr_list(tcp, tcp->u_arg[1], tcp->u_arg[2]);
 	}
@@ -164,10 +168,11 @@ SYS_FUNC(flistxattr)
 SYS_FUNC(removexattr)
 {
 	/* pathname */
+	tprints_arg_name("pathname");
 	printpath(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* name */
+	tprints_arg_next_name("name");
 	printstr(tcp, tcp->u_arg[1]);
 	return RVAL_DECODED;
 }
@@ -175,10 +180,11 @@ SYS_FUNC(removexattr)
 SYS_FUNC(fremovexattr)
 {
 	/* fd */
+	tprints_arg_name("fd");
 	printfd(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* name */
+	tprints_arg_next_name("name");
 	printstr(tcp, tcp->u_arg[1]);
 	return RVAL_DECODED;
 }
@@ -187,14 +193,15 @@ static void
 decode_dirfd_pathname_flags(struct tcb *tcp)
 {
 	/* dirfd */
+	tprints_arg_name("dirfd");
 	print_dirfd(tcp, tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* pathname */
+	tprints_arg_next_name("pathname");
 	printpath(tcp, tcp->u_arg[1]);
-	tprint_arg_next();
 
 	/* flags */
+	tprints_arg_next_name("flags");
 	printflags(xattrat_flags, tcp->u_arg[2], "AT_???");
 }
 
@@ -203,9 +210,9 @@ decode_dirfd_pathname_flags_name(struct tcb *tcp)
 {
 	/* dirfd, pathname, flags */
 	decode_dirfd_pathname_flags(tcp);
-	tprint_arg_next();
 
 	/* name */
+	tprints_arg_next_name("name");
 	printstr(tcp, tcp->u_arg[3]);
 }
 
@@ -265,14 +272,14 @@ SYS_FUNC(setxattrat)
 
 	/* dirfd, pathname, flags, name */
 	decode_dirfd_pathname_flags_name(tcp);
-	tprint_arg_next();
 
 	/* args */
+	tprints_arg_next_name("args");
 	if (!umove_xattr_args_or_printaddr(tcp, &args, addr, size))
 		print_xattr_args(tcp, &args, addr, size, true);
-	tprint_arg_next();
 
 	/* size */
+	tprints_arg_next_name("size");
 	PRINT_VAL_U(size);
 
 	return RVAL_DECODED;
@@ -288,9 +295,9 @@ SYS_FUNC(getxattrat)
 
 		/* dirfd, pathname, flags, name */
 		decode_dirfd_pathname_flags_name(tcp);
-		tprint_arg_next();
 
 		/* args */
+		tprints_arg_next_name("args");
 		if (!umove_xattr_args_or_printaddr(tcp, &args, addr, size)) {
 			if (args.size) {
 				set_tcb_priv_data(tcp, xobjdup(&args), free);
@@ -309,7 +316,7 @@ SYS_FUNC(getxattrat)
 	}
 
 	/* size */
-	tprint_arg_next();
+	tprints_arg_next_name("size");
 	PRINT_VAL_U(size);
 
 	return RVAL_DECODED;
@@ -320,7 +327,6 @@ SYS_FUNC(listxattrat)
 	if (entering(tcp)) {
 		/* dirfd, pathname, flags */
 		decode_dirfd_pathname_flags(tcp);
-		tprint_arg_next();
 	} else {
 		print_xattr_list(tcp, tcp->u_arg[3], tcp->u_arg[4]);
 	}
