@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2021 The strace developers.
+ * Copyright (c) 2017-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -63,6 +63,26 @@ print_inet_diag_req_v2(const unsigned int msg_len)
 	       msg_len, address, address);
 }
 
+static void
+test_unk_attrs(const int fd)
+{
+	static const struct strval16 unk_attrs[] = {
+		{ ENUM_KNOWN(0, INET_DIAG_REQ_NONE) },
+		{ ENUM_KNOWN(0x2, INET_DIAG_REQ_SK_BPF_STORAGES) },
+		{ ARG_XLAT_UNKNOWN(0x4, "INET_DIAG_REQ_???") },
+		{ ARG_XLAT_UNKNOWN(0x1ace, "INET_DIAG_REQ_???") },
+	};
+	static const char buf[4] = { 0xde, 0xad, 0xfa, 0xce };
+
+	for (size_t i = 0; i < ARRAY_SIZE(unk_attrs); i++) {
+		TEST_NLATTR_(fd, nlh0, hdrlen,
+			     init_inet_diag_req_v2, print_inet_diag_req_v2,
+			     unk_attrs[i].val, unk_attrs[i].str,
+			     sizeof(buf), buf, sizeof(buf),
+			     print_quoted_hex(buf, sizeof(buf)));
+	}
+}
+
 static void
 test_inet_diag_bc_op(const int fd)
 {
@@ -85,7 +105,7 @@ test_inet_diag_bc_op(const int fd)
 static void
 print_inet_diag_bc_op(const char *const code)
 {
-	printf("{{code=%s, yes=0, no=0}, ", code);
+	printf("{code=%s, yes=0, no=0}, ", code);
 }
 
 static void
@@ -110,15 +130,14 @@ test_inet_diag_bc_s_cond(const int fd)
 		    INET_DIAG_REQ_BYTECODE,
 		    plen, buf, plen,
 		    print_inet_diag_bc_op("INET_DIAG_BC_S_COND");
-		    print_quoted_hex(buf + sizeof(op), plen - sizeof(op));
-		    printf("}"));
+		    print_quoted_hex(buf + sizeof(op), plen - sizeof(op)));
 
 	TEST_NLATTR(fd, nlh0, hdrlen,
 		    init_inet_diag_req_v2, print_inet_diag_req_v2,
 		    INET_DIAG_REQ_BYTECODE,
 		    sizeof(buf), buf, sizeof(buf) - 1,
 		    print_inet_diag_bc_op("INET_DIAG_BC_S_COND");
-		    printf("%p}", RTA_DATA(TEST_NLATTR_nla) + sizeof(op)));
+		    printf("%p", RTA_DATA(TEST_NLATTR_nla) + sizeof(op)));
 
 	memcpy(buf + sizeof(op), &cond, sizeof(cond));
 	TEST_NLATTR(fd, nlh0, hdrlen,
@@ -131,7 +150,7 @@ test_inet_diag_bc_s_cond(const int fd)
 		    PRINT_FIELD_U(cond, prefix_len);
 		    printf(", ");
 		    PRINT_FIELD_U(cond, port);
-		    printf("}}"));
+		    printf("}"));
 }
 
 static void
@@ -168,7 +187,7 @@ test_in_addr(const int fd)
 		    print_inet_diag_hostcond("AF_INET");
 		    printf("addr=");
 		    print_quoted_hex(pattern, plen - sizeof(op) - sizeof(cond));
-		    printf("}}"));
+		    printf("}"));
 
 	TEST_NLATTR(fd, nlh0, hdrlen,
 		    init_inet_diag_req_v2, print_inet_diag_req_v2,
@@ -176,7 +195,7 @@ test_in_addr(const int fd)
 		    sizeof(buf), buf, sizeof(buf) - 1,
 		    print_inet_diag_bc_op("INET_DIAG_BC_S_COND");
 		    print_inet_diag_hostcond("AF_INET");
-		    printf("addr=%p}}",
+		    printf("addr=%p}",
 			   RTA_DATA(TEST_NLATTR_nla)
 			   + sizeof(op) + sizeof(cond)));
 
@@ -187,7 +206,7 @@ test_in_addr(const int fd)
 		    sizeof(buf), buf, sizeof(buf),
 		    print_inet_diag_bc_op("INET_DIAG_BC_S_COND");
 		    print_inet_diag_hostcond("AF_INET");
-		    printf("addr=inet_addr(\"%s\")}}", address));
+		    printf("addr=inet_addr(\"%s\")}", address));
 }
 
 static void
@@ -219,7 +238,7 @@ test_in6_addr(const int fd)
 		    print_inet_diag_hostcond("AF_INET6");
 		    printf("addr=");
 		    print_quoted_hex(pattern, plen - sizeof(op) - sizeof(cond));
-		    printf("}}"));
+		    printf("}"));
 
 	TEST_NLATTR(fd, nlh0, hdrlen,
 		    init_inet_diag_req_v2, print_inet_diag_req_v2,
@@ -227,7 +246,7 @@ test_in6_addr(const int fd)
 		    sizeof(buf), buf, sizeof(buf) - 1,
 		    print_inet_diag_bc_op("INET_DIAG_BC_S_COND");
 		    print_inet_diag_hostcond("AF_INET6");
-		    printf("addr=%p}}",
+		    printf("addr=%p}",
 			   RTA_DATA(TEST_NLATTR_nla)
 			   + sizeof(op) + sizeof(cond)));
 
@@ -238,7 +257,7 @@ test_in6_addr(const int fd)
 		    sizeof(buf), buf, sizeof(buf),
 		    print_inet_diag_bc_op("INET_DIAG_BC_S_COND");
 		    print_inet_diag_hostcond("AF_INET6");
-		    printf("inet_pton(AF_INET6, \"%s\", &addr)}}", address6));
+		    printf("inet_pton(AF_INET6, \"%s\", &addr)}", address6));
 }
 
 static void
@@ -257,15 +276,14 @@ test_inet_diag_bc_dev_cond(const int fd)
 		    INET_DIAG_REQ_BYTECODE,
 		    sizeof(buf) - 1, buf, sizeof(buf) - 1,
 		    print_inet_diag_bc_op("INET_DIAG_BC_DEV_COND");
-		    print_quoted_hex(pattern, sizeof(ifindex) - 1);
-		    printf("}"));
+		    print_quoted_hex(pattern, sizeof(ifindex) - 1));
 
 	TEST_NLATTR(fd, nlh0, hdrlen,
 		    init_inet_diag_req_v2, print_inet_diag_req_v2,
 		    INET_DIAG_REQ_BYTECODE,
 		    sizeof(buf), buf, sizeof(buf) - 1,
 		    print_inet_diag_bc_op("INET_DIAG_BC_DEV_COND");
-		    printf("%p}", RTA_DATA(TEST_NLATTR_nla) + sizeof(op)));
+		    printf("%p", RTA_DATA(TEST_NLATTR_nla) + sizeof(op)));
 
 	memcpy(buf + sizeof(op), &ifindex, sizeof(ifindex));
 	TEST_NLATTR(fd, nlh0, hdrlen,
@@ -273,7 +291,7 @@ test_inet_diag_bc_dev_cond(const int fd)
 		    INET_DIAG_REQ_BYTECODE,
 		    sizeof(buf), buf, sizeof(buf),
 		    print_inet_diag_bc_op("INET_DIAG_BC_DEV_COND");
-		    printf(IFINDEX_LO_STR "}"));
+		    printf(IFINDEX_LO_STR));
 }
 
 static void
@@ -301,15 +319,14 @@ test_inet_diag_bc_s_le(const int fd)
 		    INET_DIAG_REQ_BYTECODE,
 		    plen, buf, plen,
 		    print_inet_diag_bc_op("INET_DIAG_BC_S_LE");
-		    print_quoted_hex(buf + sizeof(op[0]), plen - sizeof(op[0]));
-		    printf("}"));
+		    print_quoted_hex(buf + sizeof(op[0]), plen - sizeof(op[0])));
 
 	TEST_NLATTR(fd, nlh0, hdrlen,
 		    init_inet_diag_req_v2, print_inet_diag_req_v2,
 		    INET_DIAG_REQ_BYTECODE,
 		    sizeof(buf), buf, sizeof(buf) - 1,
 		    print_inet_diag_bc_op("INET_DIAG_BC_S_LE");
-		    printf("%p}", RTA_DATA(TEST_NLATTR_nla) + sizeof(op[0])));
+		    printf("%p", RTA_DATA(TEST_NLATTR_nla) + sizeof(op[0])));
 
 	memcpy(buf + sizeof(op[0]), &op[1], sizeof(op[1]));
 	TEST_NLATTR(fd, nlh0, hdrlen,
@@ -322,7 +339,7 @@ test_inet_diag_bc_s_le(const int fd)
 		    PRINT_FIELD_U(op[1], yes);
 		    printf(", ");
 		    PRINT_FIELD_U(op[1], no);
-		    printf("}}"));
+		    printf("}"));
 };
 
 static void
@@ -346,15 +363,14 @@ test_inet_diag_bc_mark_cond(const int fd)
 		    INET_DIAG_REQ_BYTECODE,
 		    plen, buf, plen,
 		    print_inet_diag_bc_op("INET_DIAG_BC_MARK_COND");
-		    print_quoted_hex(buf + sizeof(op), plen - sizeof(op));
-		    printf("}"));
+		    print_quoted_hex(buf + sizeof(op), plen - sizeof(op)));
 
 	TEST_NLATTR(fd, nlh0, hdrlen,
 		    init_inet_diag_req_v2, print_inet_diag_req_v2,
 		    INET_DIAG_REQ_BYTECODE,
 		    sizeof(buf), buf, sizeof(buf) - 1,
 		    print_inet_diag_bc_op("INET_DIAG_BC_MARK_COND");
-		    printf("%p}", RTA_DATA(TEST_NLATTR_nla) + sizeof(op)));
+		    printf("%p", RTA_DATA(TEST_NLATTR_nla) + sizeof(op)));
 
 	memcpy(buf + sizeof(op), &markcond, sizeof(markcond));
 	TEST_NLATTR(fd, nlh0, hdrlen,
@@ -366,7 +382,7 @@ test_inet_diag_bc_mark_cond(const int fd)
 		    PRINT_FIELD_U(markcond, mark);
 		    printf(", ");
 		    PRINT_FIELD_U(markcond, mask);
-		    printf("}}"));
+		    printf("}"));
 }
 
 static void
@@ -385,8 +401,31 @@ test_inet_diag_bc_nop(const int fd)
 		    sizeof(buf), buf, sizeof(buf),
 		    print_inet_diag_bc_op("INET_DIAG_BC_AUTO");
 		    print_quoted_hex(buf + sizeof(op),
-				     sizeof(buf) - sizeof(op));
-		    printf("}"));
+				     sizeof(buf) - sizeof(op)));
+}
+
+static void
+test_inet_diag_proto(const int fd)
+{
+	static const struct strval32 protos[] = {
+		{ 0, "IPPROTO_IP" },
+		{ 3, "0x3 /* IPPROTO_??? */" },
+		{ 6, "IPPROTO_TCP" },
+		{ 144, "IPPROTO_AGGFRAG" },
+		{ 145, "0x91 /* IPPROTO_??? */" },
+		{ 256, "IPPROTO_SMC" },
+		{ 257, "0x101 /* IPPROTO_??? */" },
+		{ 262, "IPPROTO_MPTCP" },
+		{ 0xcafeface, "0xcafeface /* IPPROTO_??? */" },
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(protos); i++) {
+		TEST_NLATTR(fd, nlh0, hdrlen,
+			    init_inet_diag_req_v2, print_inet_diag_req_v2,
+			    INET_DIAG_REQ_PROTOCOL,
+			    sizeof(uint32_t), &protos[i].val, sizeof(uint32_t),
+			    printf("%s", protos[i].str));
+	}
 }
 
 int
@@ -401,6 +440,7 @@ main(void)
 				sizeof(struct in6_addr) + DEFAULT_STRLEN);
 	fill_memory_ex(pattern, sizeof(pattern), 'a', 'z' - 'a' + 1);
 
+	test_unk_attrs(fd);
 	test_inet_diag_bc_op(fd);
 	test_inet_diag_bc_s_cond(fd);
 	test_in_addr(fd);
@@ -409,6 +449,7 @@ main(void)
 	test_inet_diag_bc_s_le(fd);
 	test_inet_diag_bc_mark_cond(fd);
 	test_inet_diag_bc_nop(fd);
+	test_inet_diag_proto(fd);
 
 	printf("+++ exited with 0 +++\n");
 	return 0;
