@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@strace.io>
+ * Copyright (c) 2018-2024 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -33,7 +33,7 @@ xselect(const kernel_ulong_t args)
 int
 main(void)
 {
-	unsigned long *const args = tail_alloc(sizeof(*args) * 4);
+	TAIL_ALLOC_OBJECT_CONST_ARR(unsigned long, args, 4);
 	memset(args, 0, sizeof(*args) * 4);
 
 	xselect(0);
