@@ -2,7 +2,7 @@
  * Check decoding of add_key syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2021 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,13 +11,11 @@
 #include "tests.h"
 #include "scno.h"
 
-#ifdef __NR_add_key
+#include <inttypes.h>
+#include <stdio.h>
+#include <unistd.h>
 
-# include <inttypes.h>
-# include <stdio.h>
-# include <unistd.h>
-
-void
+static void
 print_val_str(const void *ptr, const char *str)
 {
 	if (str)
@@ -26,7 +24,7 @@ print_val_str(const void *ptr, const char *str)
 		printf("%p, ", ptr);
 }
 
-void
+static void
 do_add_key(const char *type, const char *type_str, const char *desc,
 	const char *desc_str, const char *payload, const char *payload_str,
 	size_t plen, int32_t keyring, const char *keyring_str)
@@ -56,11 +54,6 @@ main(void)
 	char *bogus_desc = tail_memdup(unterminated2, sizeof(unterminated2));
 	char *bogus_payload = tail_memdup(unterminated3, sizeof(unterminated3));
 
-	unsigned i;
-	unsigned j;
-	unsigned k;
-	unsigned l;
-
 	struct {
 		const char *type;
 		const char *str;
@@ -108,10 +101,14 @@ main(void)
 		{ -1, "KEY_SPEC_THREAD_KEYRING" },
 	};
 
-	for (i = 0; i < ARRAY_SIZE(types); i++)
-		for (j = 0; j < ARRAY_SIZE(descs); j++)
-			for (k = 0; k < ARRAY_SIZE(payloads); k++)
-				for (l = 0; l < ARRAY_SIZE(keyrings); l++)
+	for (unsigned int i = 0;
+	     i < ARRAY_SIZE(types); ++i)
+		for (unsigned int j = 0;
+		     j < ARRAY_SIZE(descs); ++j)
+			for (unsigned int k = 0;
+			     k < ARRAY_SIZE(payloads); ++k)
+				for (unsigned int l = 0;
+				     l < ARRAY_SIZE(keyrings); ++l)
 					do_add_key(types[i].type, types[i].str,
 						descs[j].desc, descs[j].str,
 						payloads[k].pload,
@@ -124,9 +121,3 @@ main(void)
 
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("__NR_add_key");
-
-#endif
