@@ -23,10 +23,8 @@
 static void *
 thread(void *arg)
 {
-	unsigned int i;
-
 	assert(chdir(".") == 0);
-	for (i = 0; i < N; ++i) {
+	for (unsigned int i = 0; i < N; ++i) {
 		assert(chdir("") == -1);
 		assert(chdir(".") == 0);
 	}
@@ -37,16 +35,15 @@ thread(void *arg)
 static int
 process(void)
 {
-	unsigned int i;
 	pthread_t t[T];
 
-	for (i = 0; i < T; ++i) {
+	for (unsigned int i = 0; i < T; ++i) {
 		errno = pthread_create(&t[i], NULL, thread, NULL);
 		if (errno)
 			perror_msg_and_fail("pthread_create");
 	}
 
-	for (i = 0; i < T; ++i) {
+	for (unsigned int i = 0; i < T; ++i) {
 		void *retval;
 		errno = pthread_join(t[i], &retval);
 		if (errno)
@@ -59,20 +56,24 @@ process(void)
 int
 main(void)
 {
-	unsigned int i;
 	pid_t p[P];
 
-	for (i = 0; i < P; ++i) {
+	for (unsigned int i = 0; i < P; ++i) {
 		p[i] = fork();
 		if (p[i] < 0)
 			perror_msg_and_fail("fork");
 		if (!p[i])
 			return process();
 	}
-	for (i = 0; i < P; ++i) {
+	for (unsigned int i = 0; i < P; ++i) {
 		int s;
+		pid_t rc;
 
-		assert(waitpid(p[i], &s, 0) == p[i]);
+		while ((rc = waitpid(p[i], &s, 0)) != p[i]) {
+			if (rc < 0 && errno == EINTR)
+				continue;
+			perror_msg_and_fail("waitpid: %d", p[i]);
+		}
 		assert(WIFEXITED(s));
 		if (WEXITSTATUS(s))
 			return WEXITSTATUS(s);
