@@ -1,7 +1,7 @@
 /*
  * Check kernel version decoding.
  *
- * Copyright (c) 2015-2021 The strace developers.
+ * Copyright (c) 2015-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -34,9 +34,9 @@ static void
 print_bpf_attr(void)
 {
 #if XLAT_RAW
-	printf("{prog_type=0x20"
+	printf("{prog_type=0x21"
 #else
-	printf("{prog_type=0x20 /* BPF_PROG_TYPE_??? */"
+	printf("{prog_type=0x21 /* BPF_PROG_TYPE_??? */"
 #endif
 		", insn_cnt=3134983661"
 		", insns=NULL"
@@ -72,7 +72,16 @@ print_bpf_attr(void)
 		", line_info_cnt=0"
 		", attach_btf_id=0"
 		", attach_prog_fd=0"
-		", fd_array=NULL}");
+		", core_relo_cnt=0"
+		", fd_array=NULL"
+		", core_relos=NULL"
+		", core_relo_rec_size=0"
+		", log_true_size=0"
+		", prog_token_fd=0"
+		", fd_array_cnt=0"
+		", signature=NULL"
+		", signature_size=0"
+		", keyring_id=0}");
 }
 
 int
@@ -80,7 +89,7 @@ main(void)
 {
 	long ret;
 	struct BPF_PROG_LOAD_struct prog = {
-		.prog_type = 32,
+		.prog_type = 33,
 		.insn_cnt = 0xbadc0ded,
 		.insns = 0,
 		.license = 0,
