@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@strace.io>
+ * Copyright (c) 2016-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,14 +8,9 @@
 
 #include "tests.h"
 #include "scno.h"
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_SET_SECCOMP && defined __NR_exit
-
-# include <stdio.h>
-# include <unistd.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/prctl.h>
 
 int
 main(void)
@@ -23,16 +18,19 @@ main(void)
 	static const char text1[] =
 		"prctl(PR_SET_SECCOMP, SECCOMP_MODE_STRICT) = 0\n";
 	static const char text2[] = "+++ exited with 0 +++\n";
+	int rc;
 
-	int rc = prctl(PR_SET_SECCOMP, -1L, 1, 2, 3);
+	prctl_marker();
+
+	rc = prctl(PR_SET_SECCOMP, -1L, 1, 2, 3);
 	printf("prctl(PR_SET_SECCOMP, %#lx /* SECCOMP_MODE_??? */, 0x1, 0x2, 0x3)"
-	       " = %d %s (%m)\n", -1L, rc, errno2name());
+	       " = %s\n", -1L, sprintrc(rc));
 	fflush(stdout);
 
 	rc = prctl(PR_SET_SECCOMP, 1);
 	if (rc) {
 		printf("prctl(PR_SET_SECCOMP, SECCOMP_MODE_STRICT)"
-		       " = %d %s (%m)\n", rc, errno2name());
+		       " = %s\n", sprintrc(rc));
 		fflush(stdout);
 		rc = 0;
 	} else {
@@ -46,9 +44,3 @@ main(void)
 	rc += write(1, text2, LENGTH_OF(text2)) != LENGTH_OF(text2);
 	return !!syscall(__NR_exit, rc);
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_SECCOMP && __NR_exit")
-
-#endif
