@@ -2,7 +2,7 @@
  * Check decoding of io_uring_register syscall.
  *
  * Copyright (c) 2019 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2019-2022 The strace developers.
+ * Copyright (c) 2019-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,6 +16,9 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+
+#include "kernel_time_types.h"
+#define UAPI_LINUX_IO_URING_H_SKIP_LINUX_TIME_TYPES_H
 #include <linux/io_uring.h>
 
 /* From tests/bpf.c */
@@ -150,7 +153,7 @@ main(void)
 			.iov_len = sizeof(path_null)
 		}
 	};
-	const struct iovec *arg_iov = tail_memdup(iov, sizeof(iov));
+	const struct iovec *const arg_iov = tail_memdup(iov, sizeof(iov));
 
 	skip_if_unavailable("/proc/self/fd/");
 
@@ -165,11 +168,14 @@ main(void)
 
 	int fds[] = { fd_full, fd_null, -1, -2, -3 };
 	const char *paths[ARRAY_SIZE(fds)] = { path_full, path_null };
-	const int *arg_fds = tail_memdup(fds, sizeof(fds));
+	const int *const arg_fds = tail_memdup(fds, sizeof(fds));
 
 
 	/* Invalid op */
-	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 24 };
+	static const unsigned int invalid_ops[] = { 0x7fffffffU, 36 };
+	static const struct strval32 op_flags[] = {
+		{ ARG_STR(IORING_REGISTER_USE_REGISTERED_RING) },
+	};
 
 	for (size_t i = 0; i < ARRAY_SIZE(invalid_ops); i++) {
 		sys_io_uring_register(fd_null, invalid_ops[i], path_null,
@@ -178,6 +184,18 @@ main(void)
 		       NRAW(" /* IORING_REGISTER_??? */") ", %p, %u) = %s\n",
 		       fd_null, path_null, invalid_ops[i], path_null,
 		       0xdeadbeef, errstr);
+
+		for (size_t j = 0; j < ARRAY_SIZE(op_flags); ++j) {
+			sys_io_uring_register(fd_null, invalid_ops[i] |
+						       op_flags[j].val,
+					      path_null, 0xdeadbeef);
+			printf("io_uring_register(%u, %#x"
+			       NRAW(" /* IORING_REGISTER_??? */") "|" XLAT_FMT
+			       ", %p, %u) = %s\n",
+			       fd_null, invalid_ops[i],
+			       XLAT_SEL(op_flags[j].val, op_flags[j].str),
+			       path_null, 0xdeadbeef, errstr);
+		}
 	}
 
 
@@ -202,6 +220,18 @@ main(void)
 		       fd_null, path_null,
 		       XLAT_SEL(no_arg_ops[i].op, no_arg_ops[i].str),
 		       path_null, 0xdeadbeef, errstr);
+
+		for (size_t j = 0; j < ARRAY_SIZE(op_flags); ++j) {
+			sys_io_uring_register(fd_null, no_arg_ops[i].op |
+						       op_flags[j].val,
+					      path_null, 0xdeadbeef);
+			printf("io_uring_register(%u, " XLAT_FMT "|" XLAT_FMT
+			       ", %p, %u) = %s\n",
+			       fd_null,
+			       XLAT_SEL(no_arg_ops[i].op, no_arg_ops[i].str),
+			       XLAT_SEL(op_flags[j].val, op_flags[j].str),
+			       path_null, 0xdeadbeef, errstr);
+		}
 	}
 
 
@@ -272,7 +302,7 @@ main(void)
 	       fd_null, path_null, fd_full, path_full, fd_null, path_null,
 	       (unsigned int) ARRAY_SIZE(fds), errstr);
 
-	struct io_uring_probe *probe = tail_alloc(sizeof(*probe) +
+	struct io_uring_probe *const probe = tail_alloc(sizeof(*probe) +
 		       (DEFAULT_STRLEN + 1) * sizeof(struct io_uring_probe_op));
 
 
@@ -340,12 +370,12 @@ main(void)
 	probe->ops[0].flags = 0;
 	probe->ops[0].resv2 = 0xbeefface;
 
-	probe->ops[1].op = 46;
+	probe->ops[1].op = 62;
 	probe->ops[1].resv = 0;
 	probe->ops[1].flags = IO_URING_OP_SUPPORTED;
 	probe->ops[1].resv2 = 0xdeadc0de;
 
-	probe->ops[2].op = 47;
+	probe->ops[2].op = 63;
 	probe->ops[2].resv = 0xaf;
 	probe->ops[2].flags = 0xbeef;
 	probe->ops[2].resv2 = 0;
@@ -360,32 +390,32 @@ main(void)
 	       ", ops_len=%hhu, resv2=[0, %#x, 0], ops=["
 	       "{op=" XLAT_FMT_U ", resv=0xde, flags=0, resv2=0xbeefface}, "
 	       "{op=" XLAT_FMT_U ", flags=" XLAT_FMT ", resv2=0xdeadc0de}, "
-	       "{op=47" NRAW(" /* IORING_OP_??? */") ", resv=0xaf, flags="
+	       "{op=63" NRAW(" /* IORING_OP_??? */") ", resv=0xaf, flags="
 	       XLAT_FMT "}, {op=254" NRAW(" /* IORING_OP_??? */")
 	       ", flags=0xc0de" NRAW(" /* IO_URING_OP_??? */") "}]}"
 #if RETVAL_INJECTED
 	       " => {last_op=" XLAT_FMT_U ", ops_len=%hhu, resv2=[0, %#x, 0], "
 	       "ops=[{op=" XLAT_FMT_U ", resv=0xde, flags=0, resv2=0xbeefface}"
 	       ", {op=" XLAT_FMT_U ", flags=" XLAT_FMT ", resv2=0xdeadc0de}"
-	       ", {op=47" NRAW(" /* IORING_OP_??? */") ", resv=0xaf, flags="
+	       ", {op=63" NRAW(" /* IORING_OP_??? */") ", resv=0xaf, flags="
 	       XLAT_FMT "}, {op=254" NRAW(" /* IORING_OP_??? */")
 	       ", flags=0xc0de" NRAW(" /* IO_URING_OP_??? */") "}, ...]}"
 #endif
 	       ", 4) = %s\n",
 	       fd_null, path_null, XLAT_ARGS(IORING_REGISTER_PROBE),
 	       XLAT_ARGS(IORING_OP_EPOLL_CTL), probe->ops_len, probe->resv2[1],
-	       XLAT_ARGS(IORING_OP_NOP), XLAT_ARGS(IORING_OP_URING_CMD),
+	       XLAT_ARGS(IORING_OP_NOP), XLAT_ARGS(IORING_OP_PIPE),
 	       XLAT_ARGS(IO_URING_OP_SUPPORTED),
 	       XLAT_ARGS(IO_URING_OP_SUPPORTED|0xbeee),
 #if RETVAL_INJECTED
 	       XLAT_ARGS(IORING_OP_EPOLL_CTL), probe->ops_len, probe->resv2[1],
-	       XLAT_ARGS(IORING_OP_NOP), XLAT_ARGS(IORING_OP_URING_CMD),
+	       XLAT_ARGS(IORING_OP_NOP), XLAT_ARGS(IORING_OP_PIPE),
 	       XLAT_ARGS(IO_URING_OP_SUPPORTED),
 	       XLAT_ARGS(IO_URING_OP_SUPPORTED|0xbeee),
 #endif
 	       errstr);
 
-	probe->last_op = 47;
+	probe->last_op = 63;
 	probe->resv2[1] = 0;
 	fill_memory_ex(probe->ops, sizeof(probe->ops[0]) * (DEFAULT_STRLEN + 1),
 		    0x40, 0x80);
@@ -394,7 +424,7 @@ main(void)
 	printf("io_uring_register(%u<%s>, " XLAT_FMT,
 	       fd_null, path_null, XLAT_ARGS(IORING_REGISTER_PROBE));
 	for (size_t c = 0; c < 1 + RETVAL_INJECTED; c++) {
-		printf("%s{last_op=47" NRAW(" /* IORING_OP_??? */")
+		printf("%s{last_op=63" NRAW(" /* IORING_OP_??? */")
 		       ", ops_len=%hhu, ops=[",
 		       c ? " => " : ", ", probe->ops_len);
 		for (size_t i = 0; i < DEFAULT_STRLEN; i++) {
@@ -456,18 +486,17 @@ main(void)
 		{ ARG_STR(IORING_RESTRICTION_REGISTER_OP), true,
 		  "register_op=", ARG_STR(IORING_REGISTER_BUFFERS), true },
 		{ ARG_STR(IORING_RESTRICTION_REGISTER_OP), true,
-		  "register_op=", ARG_STR(IORING_UNREGISTER_PBUF_RING),
-		  true },
+		  "register_op=", ARG_STR(IORING_REGISTER_QUERY), true },
 		{ ARG_STR(IORING_RESTRICTION_REGISTER_OP), true,
-		  "register_op=", 24, " /* IORING_REGISTER_??? */", false },
+		  "register_op=", 36, " /* IORING_REGISTER_??? */", false },
 		{ ARG_STR(IORING_RESTRICTION_REGISTER_OP), true,
 		  "register_op=", 255, " /* IORING_REGISTER_??? */", false },
 		{ ARG_STR(IORING_RESTRICTION_SQE_OP), true,
 		  "sqe_op=", ARG_STR(IORING_OP_NOP), true },
 		{ ARG_STR(IORING_RESTRICTION_SQE_OP), true,
-		  "sqe_op=", ARG_STR(IORING_OP_URING_CMD), true },
+		  "sqe_op=", ARG_STR(IORING_OP_PIPE), true },
 		{ ARG_STR(IORING_RESTRICTION_SQE_OP), true,
-		  "sqe_op=", 47, " /* IORING_OP_??? */", false },
+		  "sqe_op=", 63, " /* IORING_OP_??? */", false },
 		{ ARG_STR(IORING_RESTRICTION_SQE_OP), true,
 		  "sqe_op=", 255, " /* IORING_OP_??? */", false },
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_ALLOWED), true,
@@ -495,11 +524,10 @@ main(void)
 		{ 4, " /* IORING_RESTRICTION_??? */", false, "", 239 },
 		{ 137, " /* IORING_RESTRICTION_??? */", false, "", 0 },
 	};
-	struct io_uring_restriction *restrictions =
-			tail_alloc(sizeof(*restrictions)
-				   * ARRAY_SIZE(restrictions_data));
-	char *restrictions_end = (char *) (restrictions
-					   + ARRAY_SIZE(restrictions_data));
+	TAIL_ALLOC_OBJECT_CONST_ARR(struct io_uring_restriction, restrictions,
+				    ARRAY_SIZE(restrictions_data));
+	char *const restrictions_end =
+		(char *) (restrictions + ARRAY_SIZE(restrictions_data));
 
 	sys_io_uring_register(fd_null, IORING_REGISTER_RESTRICTIONS, NULL,
 			      0xfacefeed);
@@ -657,11 +685,11 @@ main(void)
 	};
 	static const uint64_t tags[] = { 0x1337, 1, 0xdead, 0xfacefeed,
 					 0xbadc0deddadfacedULL, 0 };
-	const uint64_t *arg_tags = tail_memdup(tags, sizeof(tags));
+	const uint64_t *const arg_tags = tail_memdup(tags, sizeof(tags));
 
-	struct io_uring_rsrc_register *bogus_rsrc_reg = tail_alloc(24);
-	struct io_uring_rsrc_register *rsrc_reg = tail_alloc(sizeof(*rsrc_reg));
-	struct io_uring_rsrc_register *big_rsrc_reg =
+	struct io_uring_rsrc_register *const bogus_rsrc_reg = tail_alloc(24);
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_rsrc_register, rsrc_reg);
+	struct io_uring_rsrc_register *const big_rsrc_reg =
 		tail_alloc(sizeof(*big_rsrc_reg) + 8);
 
 	fill_memory(big_rsrc_reg, sizeof(*big_rsrc_reg) + 8);
@@ -762,9 +790,9 @@ main(void)
 		{ 16, "IORING_REGISTER_BUFFERS_UPDATE" },
 	};
 
-	struct io_uring_rsrc_update2 *bogus_rsrc_upd = tail_alloc(24);
-	struct io_uring_rsrc_update2 *rsrc_upd = tail_alloc(sizeof(*rsrc_upd));
-	struct io_uring_rsrc_update2 *big_rsrc_upd =
+	struct io_uring_rsrc_update2 *const bogus_rsrc_upd = tail_alloc(24);
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_rsrc_update2, rsrc_upd);
+	struct io_uring_rsrc_update2 *const big_rsrc_upd =
 		tail_alloc(sizeof(*big_rsrc_upd) + 8);
 
 	fill_memory(big_rsrc_upd, sizeof(*big_rsrc_upd) + 8);
@@ -865,7 +893,7 @@ main(void)
 		(unsigned long) 0xbadc0deddadfacedULL,
 		(unsigned long) 0xfacefeeddeadbeefULL,
 	};
-	const unsigned long *arg_aff = tail_memdup(aff, sizeof(aff));
+	const unsigned long *const arg_aff = tail_memdup(aff, sizeof(aff));
 	const unsigned long *arg_aff_end = arg_aff + ARRAY_SIZE(aff);
 
 	sys_io_uring_register(fd_null, 17, NULL, 0xfacefeed);
@@ -890,12 +918,12 @@ main(void)
 	       XLAT_KNOWN(0x11, "IORING_REGISTER_IOWQ_AFF")
 #ifdef WORDS_BIGENDIAN
 # if SIZEOF_LONG > 4
-	       ", [49, 50, 51, 54, 55, 57, 59, 60, 61, 62, 63]" /* face */
+	       ", [49 50 51 54 55 57 59 60 61 62 63]" /* face */
 # else
-	       ", [16, 18, 19, 21, 23, 25, 26, 27, 28, 30, 31]" /* dead */
+	       ", [16 18 19 21 23 25 26 27 28 30 31]" /* dead */
 # endif
 #else
-	       ", [0, 1, 2, 3, 5, 6, 7, 9, 10, 11, 12, 13, 15]" /* beef */
+	       ", [0 1 2 3 5 6 7 9 10 11 12 13 15]" /* beef */
 #endif /* WORDS_BIGENDIAN */
 	       ", 2) = %s\n",
 	       fd_null, path_null, errstr);
@@ -909,18 +937,18 @@ main(void)
 	sys_io_uring_register(fd_null, 17, arg_aff, sizeof(aff));
 	printf("io_uring_register(%u<%s>, "
 	       XLAT_KNOWN(0x11, "IORING_REGISTER_IOWQ_AFF") ", "
-	       "[0, 2, 3, 5, 6, 7, 10, 11, 13, 15" /* aced */
-	       ", 16, 17, 18, 19, 20, 22, 23, 25, 27, 28, 30, 31" /* dadf */
+	       "[0 2 3 5 6 7 10 11 13 15" /* aced */
+	       " 16 17 18 19 20 22 23 25 27 28 30 31" /* dadf */
 #if SIZEOF_LONG > 4
-	       ", 32, 34, 35, 37, 38, 39, 40, 42, 43" /* 0ded */
-	       ", 50, 51, 52, 54, 55, 57, 59, 60, 61, 63" /* badc */
-	       ", 64, 65, 66, 67, 69, 70, 71, 73, 74, 75, 76, 77, 79" /* beef */
-	       ", 80, 82, 83, 85, 87, 89, 90, 91, 92, 94, 95" /* dead feed */
-	       ", 96, 98, 99, 101, 102, 103, 105, 106, 107, 108, 109, 110, 111"
-	       ", 113, 114, 115, 118, 119, 121, 123, 124, 125, 126, 127"/*face*/
+	       " 32 34 35 37 38 39 40 42 43" /* 0ded */
+	       " 50 51 52 54 55 57 59 60 61 63" /* badc */
+	       " 64 65 66 67 69 70 71 73 74 75 76 77 79" /* beef */
+	       " 80 82 83 85 87 89 90 91 92 94 95" /* dead feed */
+	       " 96 98 99 101 102 103 105 106 107 108 109 110 111"
+	       " 113 114 115 118 119 121 123 124 125 126 127"/*face*/
 #else
-	       ", 32, 33, 34, 35, 37, 38, 39, 41, 42, 43, 44, 45, 47" /* beef */
-	       ", 48, 50, 51, 53, 55, 57, 58, 59, 60, 62, 63" /* dead */
+	       " 32 33 34 35 37 38 39 41 42 43 44 45 47" /* beef */
+	       " 48 50 51 53 55 57 58 59 60 62 63" /* dead */
 #endif
 	       "], %zu) = %s\n",
 	       fd_null, path_null, sizeof(aff), errstr);
@@ -928,7 +956,7 @@ main(void)
 
 	/* IORING_REGISTER_IOWQ_MAX_WORKERS */
 	unsigned int maxw[] = { 0, 1, 0xbedfaced };
-	const unsigned int *arg_maxw = tail_memdup(maxw, sizeof(maxw));
+	const unsigned int *const arg_maxw = tail_memdup(maxw, sizeof(maxw));
 	const unsigned int *arg_maxw_end = arg_maxw + ARRAY_SIZE(maxw);
 
 	sys_io_uring_register(fd_null, 19, NULL, 0xfacefeed);
@@ -952,20 +980,20 @@ main(void)
 	sys_io_uring_register(fd_null, 19, arg_maxw_end - 1, 2);
 	printf("io_uring_register(%u<%s>, "
 	       XLAT_KNOWN(0x13, "IORING_REGISTER_IOWQ_MAX_WORKERS") ", [["
-	       XLAT_KNOWN(0, "IO_WQ_BOUND") "] = 3202329837, ... /* %p */]"
+	       XLAT_KNOWN(0, "IO_WQ_BOUND") "]=3202329837, ... /* %p */]"
 	       ", 2) = %s\n",
 	       fd_null, path_null, arg_maxw_end, errstr);
 
 	sys_io_uring_register(fd_null, 19, arg_maxw, 3);
 	printf("io_uring_register(%u<%s>, "
 	       XLAT_KNOWN(0x13, "IORING_REGISTER_IOWQ_MAX_WORKERS") ", "
-	       "[[" XLAT_KNOWN(0, "IO_WQ_BOUND") "] = 0, ["
-	       XLAT_KNOWN(1, "IO_WQ_UNBOUND") "] = 1, ["
-	       XLAT_UNKNOWN(2, "IO_WQ_???") "] = 3202329837] => "
+	       "[[" XLAT_KNOWN(0, "IO_WQ_BOUND") "]=0, ["
+	       XLAT_KNOWN(1, "IO_WQ_UNBOUND") "]=1, ["
+	       XLAT_UNKNOWN(2, "IO_WQ_???") "]=3202329837] => "
 #if RETVAL_INJECTED
-	       "[[" XLAT_KNOWN(0, "IO_WQ_BOUND") "] = 0, ["
-	       XLAT_KNOWN(1, "IO_WQ_UNBOUND") "] = 1, ["
-	       XLAT_UNKNOWN(2, "IO_WQ_???") "] = 3202329837]"
+	       "[[" XLAT_KNOWN(0, "IO_WQ_BOUND") "]=0, ["
+	       XLAT_KNOWN(1, "IO_WQ_UNBOUND") "]=1, ["
+	       XLAT_UNKNOWN(2, "IO_WQ_???") "]=3202329837]"
 #else
 	       "%p"
 #endif
@@ -989,8 +1017,8 @@ main(void)
 	static const size_t ringfd_count = DEFAULT_STRLEN + 1;
 	static const uint32_t ringfd_off[] =
 		{ -1U, 0, 1, 2, 161803398, 3141592653, -2U };
-	TAIL_ALLOC_OBJECT_VAR_ARR(struct io_uring_rsrc_update, ringfds,
-				  ringfd_count);
+	TAIL_ALLOC_OBJECT_CONST_ARR(struct io_uring_rsrc_update, ringfds,
+				    ringfd_count);
 
 	fill_memory(ringfds, sizeof(*ringfds) * ringfd_count);
 	for (size_t i = 0; i < ringfd_count; i++) {
@@ -1079,7 +1107,7 @@ main(void)
 		{ 22, "IORING_REGISTER_PBUF_RING" },
 		{ 23, "IORING_UNREGISTER_PBUF_RING" },
 	};
-	TAIL_ALLOC_OBJECT_VAR_PTR(struct io_uring_buf_reg, buf_reg);
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_buf_reg, buf_reg);
 
 	for (size_t i = 0; i < ARRAY_SIZE(buf_reg_ops); i++) {
 		sys_io_uring_register(fd_null, buf_reg_ops[i].op, 0,
@@ -1102,13 +1130,21 @@ main(void)
 			buf_reg->ring_addr = j & 2 ? (uintptr_t) buf_reg : 0;
 			buf_reg->ring_entries = j & 4 ? 3141592653 : 0;
 			buf_reg->bgid = j & 8 ? 42069 : 0;
-			buf_reg->pad = j & 16 ? 31337 : 0;
+			buf_reg->flags = j & 16 ? 31337 : 0;
 			buf_reg->resv[0] = j &  32 ? 0xbadc0deddeadfaceULL : 0;
 			buf_reg->resv[1] = j &  64 ? 0xdecaffedbeefdeadULL : 0;
 			buf_reg->resv[2] = j & 128 ? 0xbadc0dedfacefeedULL : 0;
 
 			sys_io_uring_register(fd_null, buf_reg_ops[i].op,
 					      buf_reg, 0x42);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 66)"
+			       " = %s\n",
+			       fd_null, path_null,
+			       XLAT_SEL(buf_reg_ops[i].op, buf_reg_ops[i].str),
+			       buf_reg, errstr);
+
+			sys_io_uring_register(fd_null, buf_reg_ops[i].op,
+					      buf_reg, 1);
 			printf("io_uring_register(%u<%s>, " XLAT_FMT
 			       ", {ring_addr=",
 			       fd_null, path_null,
@@ -1117,20 +1153,477 @@ main(void)
 				printf("%p", buf_reg);
 			else
 				printf("NULL");
-			printf(", ring_entries=%s, bgid=%s%s",
+			printf(", ring_entries=%s, bgid=%s, flags=%s",
 			       j & 4 ? "3141592653" : "0",
 			       j & 8 ? "42069" : "0",
-			       j & 16 ? ", pad=0x7a69" : "");
+			       j & 16 ? "0x7a69" : "0");
 			if (j & 0xe0) {
 				printf(", resv=[%s, %s, %s]",
 				       j &  32 ? "0xbadc0deddeadface" : "0",
 				       j &  64 ? "0xdecaffedbeefdead" : "0",
 				       j & 128 ? "0xbadc0dedfacefeed" : "0");
 			}
-			printf("}, 66) = %s\n", errstr);
+			printf("}, 1) = %s\n", errstr);
 		}
 	}
 
+	/* IORING_REGISTER_SYNC_CANCEL */
+	static const struct {
+		unsigned int op;
+		const char *str;
+	} sync_cancel_reg_ops[] = {
+		{ 24, "IORING_REGISTER_SYNC_CANCEL" },
+	};
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_sync_cancel_reg,
+				    sync_cancel_reg);
+
+	for (size_t i = 0; i < ARRAY_SIZE(sync_cancel_reg_ops); i++) {
+		sys_io_uring_register(fd_null, sync_cancel_reg_ops[i].op, 0,
+				      0xdeadbeef);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT ", NULL, %u)"
+		       " = %s\n",
+		       fd_null, path_null,
+		       XLAT_SEL(sync_cancel_reg_ops[i].op,
+			        sync_cancel_reg_ops[i].str),
+		       0xdeadbeef, errstr);
+
+		sys_io_uring_register(fd_null, sync_cancel_reg_ops[i].op,
+				      sync_cancel_reg + 1, 0);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 0) = %s\n",
+		       fd_null, path_null,
+		       XLAT_SEL(sync_cancel_reg_ops[i].op, sync_cancel_reg_ops[i].str),
+		       sync_cancel_reg + 1, errstr);
+
+		for (size_t j = 0; j < 0x100; j++) {
+			memset(sync_cancel_reg, 0, sizeof(*sync_cancel_reg));
+			sync_cancel_reg->addr =
+				j & 0x1 ? (uintptr_t) sync_cancel_reg : 0;
+			sync_cancel_reg->fd = j & 0x2 ? fd_null : -1;
+			sync_cancel_reg->flags = j & 0x4 ? 0x3f : 0xffffffc0U;
+			sync_cancel_reg->timeout.tv_sec =
+				j & 0x8 ? 0xdeface1 : -1;
+			sync_cancel_reg->timeout.tv_nsec =
+				j & 0x10 ? 0xdeface2 : -1;
+			sync_cancel_reg->opcode =
+				j & 0x20 ? IORING_OP_LAST - 1
+					 : IORING_OP_LAST;
+			if (j & 0x40)
+				sync_cancel_reg->pad[6] = 0xfe;
+			if (j & 0x80)
+				sync_cancel_reg->pad2[2] = 0xbadc0de1dadface2ULL;
+
+			sys_io_uring_register(fd_null, sync_cancel_reg_ops[i].op,
+					      sync_cancel_reg, 0x42);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 66)"
+			       " = %s\n",
+			       fd_null, path_null,
+			       XLAT_SEL(sync_cancel_reg_ops[i].op,
+				        sync_cancel_reg_ops[i].str),
+			       sync_cancel_reg, errstr);
+
+			sys_io_uring_register(fd_null, sync_cancel_reg_ops[i].op,
+					      sync_cancel_reg, 1);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT
+			       ", {",
+			       fd_null, path_null,
+			       XLAT_SEL(sync_cancel_reg_ops[i].op,
+				        sync_cancel_reg_ops[i].str));
+			if (j & 0x1)
+				printf("addr=%p", sync_cancel_reg);
+			else
+				printf("addr=NULL");
+			if (j & 0x2)
+				printf(", fd=%u<%s>", fd_null, path_null);
+			else
+				printf(", fd=-1");
+			if (j & 0x4)
+				printf(", flags=" XLAT_FMT,
+				       XLAT_ARGS(IORING_ASYNC_CANCEL_ALL|IORING_ASYNC_CANCEL_FD|IORING_ASYNC_CANCEL_ANY|IORING_ASYNC_CANCEL_FD_FIXED|IORING_ASYNC_CANCEL_USERDATA|IORING_ASYNC_CANCEL_OP));
+			else
+				printf(", flags=0xffffffc0"
+				       NRAW(" /* IORING_ASYNC_CANCEL_??? */"));
+			printf(", timeout={tv_sec=%jd, tv_nsec=%jd}",
+			       (intmax_t) sync_cancel_reg->timeout.tv_sec,
+			       (intmax_t) sync_cancel_reg->timeout.tv_nsec);
+			if (j & 0x20)
+				printf(", opcode=" XLAT_FMT,
+				       XLAT_ARGS(IORING_OP_PIPE));
+			else
+				printf(", opcode=%#x"
+				       NRAW(" /* IORING_OP_??? */"),
+				       sync_cancel_reg->opcode);
+			if (j & 0x40)
+				printf(", pad=[0, 0, 0, 0, 0, 0, 0xfe]");
+			if (j & 0x80)
+				printf(", pad2=[0, 0, 0xbadc0de1dadface2]");
+			printf("}, 1) = %s\n", errstr);
+		}
+	}
+
+	/* IORING_REGISTER_FILE_ALLOC_RANGE */
+	static const struct {
+		unsigned int op;
+		const char *str;
+	} file_index_range_ops[] = {
+		{ 25, "IORING_REGISTER_FILE_ALLOC_RANGE" },
+	};
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_file_index_range,
+				    file_index_range);
+
+	for (size_t i = 0; i < ARRAY_SIZE(file_index_range_ops); i++) {
+		sys_io_uring_register(fd_null, file_index_range_ops[i].op, 0,
+				      0xdeadbeef);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT ", NULL, %u)"
+		       " = %s\n",
+		       fd_null, path_null,
+		       XLAT_SEL(file_index_range_ops[i].op,
+			        file_index_range_ops[i].str),
+		       0xdeadbeef, errstr);
+
+		sys_io_uring_register(fd_null, file_index_range_ops[i].op,
+				      file_index_range + 1, 0);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 0) = %s\n",
+		       fd_null, path_null,
+		       XLAT_SEL(file_index_range_ops[i].op, file_index_range_ops[i].str),
+		       file_index_range + 1, errstr);
+
+		for (size_t j = 0; j < (1U << 3); j++) {
+			memset(file_index_range, 0, sizeof(*file_index_range));
+			file_index_range->off = j & 1 ? 0xfacefeedU : 0;
+			file_index_range->len = j & 2 ? 0xcafef00dU : 0;
+			file_index_range->resv = j & 4 ? 0xbadc0de1dadface2ULL : 0;
+
+			sys_io_uring_register(fd_null, file_index_range_ops[i].op,
+					      file_index_range, 0x42);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 66)"
+			       " = %s\n",
+			       fd_null, path_null,
+			       XLAT_SEL(file_index_range_ops[i].op,
+				        file_index_range_ops[i].str),
+			       file_index_range, errstr);
+
+			sys_io_uring_register(fd_null, file_index_range_ops[i].op,
+					      file_index_range, 1);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT
+			       ", {off=%u, len=%u",
+			       fd_null, path_null,
+			       XLAT_SEL(file_index_range_ops[i].op,
+				        file_index_range_ops[i].str),
+			       file_index_range->off, file_index_range->len);
+			if (j & 4)
+				printf(", resv=0xbadc0de1dadface2");
+			printf("}, 1) = %s\n", errstr);
+		}
+	}
+
+	/* IORING_REGISTER_PBUF_STATUS */
+	static const struct {
+		unsigned int op;
+		const char *str;
+	} buf_status_ops[] = {
+		{ 26, "IORING_REGISTER_PBUF_STATUS" },
+	};
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_buf_status, buf_status);
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_status_ops); i++) {
+		sys_io_uring_register(fd_null, buf_status_ops[i].op, 0,
+				      0xdeadbeef);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT ", NULL, %u)"
+		       " = %s\n",
+		       fd_null, path_null,
+		       XLAT_SEL(buf_status_ops[i].op,
+			        buf_status_ops[i].str),
+		       0xdeadbeef, errstr);
+
+		sys_io_uring_register(fd_null, buf_status_ops[i].op,
+				      buf_status + 1, 0);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 0) = %s\n",
+		       fd_null, path_null,
+		       XLAT_SEL(buf_status_ops[i].op, buf_status_ops[i].str),
+		       buf_status + 1, errstr);
+
+		for (size_t j = 0; j < (1U << 3); j++) {
+			memset(buf_status, 0, sizeof(*buf_status));
+			buf_status->buf_group = j & 1 ? 0xfacefeedU : 0;
+			buf_status->head = j & 2 ? 0xcafef00dU : 0;
+			buf_status->resv[7] = j & 4 ? 0xbadc0dedU : 0;
+
+			sys_io_uring_register(fd_null, buf_status_ops[i].op,
+					      buf_status, 0x42);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 66)"
+			       " = %s\n",
+			       fd_null, path_null,
+			       XLAT_SEL(buf_status_ops[i].op,
+				        buf_status_ops[i].str),
+			       buf_status, errstr);
+
+			sys_io_uring_register(fd_null, buf_status_ops[i].op,
+					      buf_status, 1);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT ", "
+#if RETVAL_INJECTED
+			       "{buf_group=%#x, head=%#x",
+#else
+			       "%p",
+#endif
+			       fd_null, path_null,
+			       XLAT_SEL(buf_status_ops[i].op,
+				        buf_status_ops[i].str),
+#if RETVAL_INJECTED
+			       buf_status->buf_group, buf_status->head
+#else
+			       buf_status
+#endif
+			       );
+#if RETVAL_INJECTED
+			if (j & 4)
+				printf(", resv=[0, 0, 0, 0, 0, 0, 0, 0xbadc0ded]");
+			printf("}");
+#endif
+			printf(", 1) = %s\n", errstr);
+		}
+	}
+
+	/* IORING_REGISTER_NAPI, IORING_UNREGISTER_NAPI */
+	static const struct strval32 napi_ops[] = {
+		{ ARG_STR(IORING_REGISTER_NAPI) },
+		{ ARG_STR(IORING_UNREGISTER_NAPI) },
+	};
+	static const struct strval32 napi_opcodes[] = {
+		{ ARG_XLAT_KNOWN(0, "IO_URING_NAPI_REGISTER_OP") },
+		{ ARG_XLAT_KNOWN(0x1, "IO_URING_NAPI_STATIC_ADD_ID") },
+		{ ARG_XLAT_KNOWN(0x2, "IO_URING_NAPI_STATIC_DEL_ID") },
+		{ ARG_XLAT_UNKNOWN(0xff, "IO_URING_NAPI_???") }
+	};
+	static const struct strval32 napi_tracking_strategies[] = {
+		{ ARG_XLAT_KNOWN(0, "IO_URING_NAPI_TRACKING_DYNAMIC") },
+		{ ARG_XLAT_KNOWN(0x1, "IO_URING_NAPI_TRACKING_STATIC") },
+		{ ARG_XLAT_KNOWN(0xff, "IO_URING_NAPI_TRACKING_INACTIVE") },
+		{ ARG_XLAT_UNKNOWN(0xfacefeed, "IO_URING_NAPI_TRACKING_???") }
+	};
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_napi, napi);
+
+	for (size_t i = 0; i < ARRAY_SIZE(napi_ops); i++) {
+		sys_io_uring_register(fd_null, napi_ops[i].val, 0, 0xdeadbeef);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT ", NULL, %u)"
+		       " = %s\n",
+		       fd_null, path_null,
+		       XLAT_SEL(napi_ops[i].val,
+			        napi_ops[i].str),
+		       0xdeadbeef, errstr);
+
+		sys_io_uring_register(fd_null, napi_ops[i].val, napi + 1, 0);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 0) = %s\n",
+		       fd_null, path_null,
+		       XLAT_SEL(napi_ops[i].val, napi_ops[i].str),
+		       napi + 1, errstr);
+
+		for (size_t j = 0; j < (1U << 4); j++) {
+			const unsigned int tracking_idx = (j >> 2) & 3;
+			memset(napi, 0, sizeof(*napi));
+			napi->busy_poll_to = j & 1 ? 0xfacefeedU : 0;
+			napi->prefer_busy_poll = j & 2 ? 0xfe : 0;
+			napi->opcode = napi_opcodes[j & 3].val;
+			napi->pad[1] = j & 4 ? 0x10 : 0;
+			napi->op_param = napi_tracking_strategies[tracking_idx].val;
+			napi->resv = j & 8 ? 0xbadc0dedU : 0;
+
+			sys_io_uring_register(fd_null, napi_ops[i].val, napi,
+					      0x42);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 66)"
+			       " = %s\n",
+			       fd_null, path_null,
+			       XLAT_SEL(napi_ops[i].val,
+				        napi_ops[i].str),
+			       napi, errstr);
+
+			sys_io_uring_register(fd_null, napi_ops[i].val, napi, 1);
+			printf("io_uring_register(%u<%s>, " XLAT_FMT ", ",
+			       fd_null, path_null,
+			       XLAT_SEL(napi_ops[i].val,
+				        napi_ops[i].str));
+			if (i == 0 || RETVAL_INJECTED) {
+				printf("{busy_poll_to=%#x, prefer_busy_poll=%#x",
+				       napi->busy_poll_to,
+				       napi->prefer_busy_poll);
+				printf(", opcode=%s", napi_opcodes[j & 3].str);
+				if (j & 4)
+					printf(", pad=[0, 0x10]");
+				if (napi->opcode == 0)
+					printf(", op_param=%s",
+					       napi_tracking_strategies[tracking_idx].str);
+				else
+					printf(", op_param=%#x", napi->op_param);
+				if (j & 8)
+					printf(", resv=0xbadc0ded");
+				printf("}");
+			} else
+				printf("%p", napi);
+			if (i == 0 && RETVAL_INJECTED) {
+				printf(" => {busy_poll_to=%#x, prefer_busy_poll=%#x",
+				       napi->busy_poll_to,
+				       napi->prefer_busy_poll);
+				printf(", opcode=%s", napi_opcodes[j & 3].str);
+				if (j & 4)
+					printf(", pad=[0, 0x10]");
+				if (napi->opcode == 0)
+					printf(", op_param=%s",
+					       napi_tracking_strategies[tracking_idx].str);
+				else
+					printf(", op_param=%#x", napi->op_param);
+				if (j & 8)
+					printf(", resv=0xbadc0ded");
+				printf("}");
+			}
+			printf(", 1) = %s\n", errstr);
+		}
+	}
+
+	/* IORING_REGISTER_CLOCK */
+	static const struct strval32 clock_ops =
+		{ ARG_STR(IORING_REGISTER_CLOCK) };
+
+	sys_io_uring_register(fd_null, clock_ops.val, 0, 1);
+	printf("io_uring_register(%u<%s>, " XLAT_FMT ", NULL, 1) = %s\n",
+	       fd_null, path_null,
+	       XLAT_SEL(clock_ops.val, clock_ops.str),
+	       errstr);
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_clock_register,
+				    clock_register);
+
+	sys_io_uring_register(fd_null, clock_ops.val, clock_register, 0x42);
+	printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 66) = %s\n",
+	       fd_null, path_null,
+	       XLAT_SEL(clock_ops.val, clock_ops.str),
+	       clock_register, errstr);
+
+	sys_io_uring_register(fd_null, clock_ops.val, clock_register + 1, 0);
+	printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 0) = %s\n",
+	       fd_null, path_null,
+	       XLAT_SEL(clock_ops.val, clock_ops.str),
+	       clock_register + 1, errstr);
+
+	sys_io_uring_register(fd_null, clock_ops.val,
+			      (char *) clock_register + 1, 0);
+	printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 0) = %s\n",
+	       fd_null, path_null,
+	       XLAT_SEL(clock_ops.val, clock_ops.str),
+	       (char *) clock_register + 1, errstr);
+
+	static const struct strval32 clockids[] = {
+		{ ARG_XLAT_KNOWN(0, "CLOCK_REALTIME") },
+		{ ARG_XLAT_KNOWN(0x1, "CLOCK_MONOTONIC") },
+		{ ARG_XLAT_KNOWN(0x2, "CLOCK_PROCESS_CPUTIME_ID") },
+		{ ARG_XLAT_KNOWN(0x3, "CLOCK_THREAD_CPUTIME_ID") },
+		{ ARG_XLAT_KNOWN(0x4, "CLOCK_MONOTONIC_RAW") },
+		{ ARG_XLAT_KNOWN(0x5, "CLOCK_REALTIME_COARSE") },
+		{ ARG_XLAT_KNOWN(0x6, "CLOCK_MONOTONIC_COARSE") },
+		{ ARG_XLAT_KNOWN(0x7, "CLOCK_BOOTTIME") },
+		{ ARG_XLAT_KNOWN(0x8, "CLOCK_REALTIME_ALARM") },
+		{ ARG_XLAT_KNOWN(0x9, "CLOCK_BOOTTIME_ALARM") },
+		{ ARG_XLAT_KNOWN(0xa, "CLOCK_SGI_CYCLE") },
+		{ ARG_XLAT_KNOWN(0xb, "CLOCK_TAI") },
+		{ ARG_XLAT_UNKNOWN(0xc, "CLOCK_???") },
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(clockids); ++i) {
+		memset(clock_register, 0, sizeof(*clock_register));
+		clock_register->clockid = clockids[i].val;
+		clock_register->__resv[0] = i & 1 ? 0xdefaced1 : 0;
+		clock_register->__resv[1] = i & 2 ? 0xdefaced2 : 0;
+		clock_register->__resv[2] = i & 4 ? 0xdefaced3 : 0;
+		sys_io_uring_register(fd_null, clock_ops.val, clock_register, 0);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT
+		        ", {clockid=%s",
+		       fd_null, path_null,
+		       XLAT_SEL(clock_ops.val, clock_ops.str),
+		       clockids[i].str);
+		if (i & 7)
+			printf(", __resv=[%#x, %#x, %#x]",
+			       clock_register->__resv[0],
+			       clock_register->__resv[1],
+			       clock_register->__resv[2]);
+		printf("}, 0) = %s\n", errstr);
+	}
+
+	/* IORING_REGISTER_CLONE_BUFFERS */
+	static const struct strval32 clone_buffers_ops =
+		{ ARG_STR(IORING_REGISTER_CLONE_BUFFERS) };
+
+	sys_io_uring_register(fd_null, clone_buffers_ops.val, 0, 2);
+	printf("io_uring_register(%u<%s>, " XLAT_FMT ", NULL, 2) = %s\n",
+	       fd_null, path_null,
+	       XLAT_SEL(clone_buffers_ops.val, clone_buffers_ops.str),
+	       errstr);
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct io_uring_clone_buffers,
+				    clone_buffers);
+
+	sys_io_uring_register(fd_null, clone_buffers_ops.val,
+			      clone_buffers, 0x42);
+	printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 66) = %s\n",
+	       fd_null, path_null,
+	       XLAT_SEL(clone_buffers_ops.val, clone_buffers_ops.str),
+	       clone_buffers, errstr);
+
+	sys_io_uring_register(fd_null, clone_buffers_ops.val,
+			      clone_buffers + 1, 1);
+	printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 1) = %s\n",
+	       fd_null, path_null,
+	       XLAT_SEL(clone_buffers_ops.val, clone_buffers_ops.str),
+	       clone_buffers + 1, errstr);
+
+	sys_io_uring_register(fd_null, clone_buffers_ops.val,
+			      (char *) clone_buffers + 1, 1);
+	printf("io_uring_register(%u<%s>, " XLAT_FMT ", %p, 1) = %s\n",
+	       fd_null, path_null,
+	       XLAT_SEL(clone_buffers_ops.val, clone_buffers_ops.str),
+	       (char *) clone_buffers + 1, errstr);
+
+	static const struct strval32 clone_buffers_flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1, "IORING_REGISTER_SRC_REGISTERED") },
+		{ ARG_XLAT_KNOWN(0x2, "IORING_REGISTER_DST_REPLACE") },
+		{ ARG_XLAT_UNKNOWN(0x4, "IORING_REGISTER_???") },
+		{ ARG_XLAT_UNKNOWN(0xfffffffc, "IORING_REGISTER_???") },
+		{ ARG_XLAT_KNOWN(0xffffffff,
+				 "IORING_REGISTER_SRC_REGISTERED|"
+				 "IORING_REGISTER_DST_REPLACE|"
+				 "0xfffffffc") },
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(clone_buffers_flags); ++i) {
+		const size_t pad_len = ARRAY_SIZE(clone_buffers->pad);
+		memset(clone_buffers, 0, sizeof(*clone_buffers));
+		clone_buffers->src_fd = fd_full;
+		clone_buffers->flags = clone_buffers_flags[i].val;
+		clone_buffers->src_off = 0xfacefed1 + i;
+		clone_buffers->dst_off = 0xfacefed2 + i;
+		clone_buffers->nr = 0xfacefed3 + i;
+		clone_buffers->pad[0] = i & 1 ? 0xdefaced1 : 0;
+		clone_buffers->pad[pad_len - 1] = i & 2 ? 0xdefaced2 : 0;
+		sys_io_uring_register(fd_null, clone_buffers_ops.val,
+				      clone_buffers, 1);
+		printf("io_uring_register(%u<%s>, " XLAT_FMT
+		        ", {src_fd=%u<%s>, flags=%s"
+			", src_off=%u, dst_off=%u, nr=%u",
+		       fd_null, path_null,
+		       XLAT_SEL(clone_buffers_ops.val, clone_buffers_ops.str),
+		       fd_full, path_full,
+		       clone_buffers_flags[i].str,
+		       clone_buffers->src_off,
+		       clone_buffers->dst_off,
+		       clone_buffers->nr);
+			if (i & 3) {
+				printf(", pad=[");
+				for (size_t j = 0; j < pad_len; ++j)
+					printf("%s%#x", j ? ", " : "",
+					       clone_buffers->pad[j]);
+				printf("]");
+			}
+		printf("}, 1) = %s\n", errstr);
+	}
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
