@@ -1,7 +1,7 @@
 /*
  * Check decoding of prctl PR_SVE_SET_VL/PR_SVE_GET_VL operations.
  *
- * Copyright (c) 2021 The strace developers.
+ * Copyright (c) 2021-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -43,12 +43,28 @@ main(void)
 		   (unsigned long) 0xff, sprintrc(rc));
 
 	rc = syscall(__NR_prctl, PR_SVE_GET_VL);
-	printf("prctl(PR_SVE_GET_VL) = %s", sprintrc(rc));
+	printf("prctl(PR_SVE_GET_VL) = ");
 	if (rc >= 0) {
-		printf(" (PR_SVE_SET_VL_ONEXEC|PR_SVE_VL_INHERIT|%#lx)",
-			   (unsigned long) 0xff);
+		printf("%#lx", rc);
+		if (rc > 0xffff) {
+			printf(" (");
+			if (rc & PR_SVE_SET_VL_ONEXEC)
+				printf("PR_SVE_SET_VL_ONEXEC");
+			if (rc & PR_SVE_VL_INHERIT) {
+				printf("%sPR_SVE_VL_INHERIT",
+				       rc & PR_SVE_SET_VL_ONEXEC ? "|" : "");
+			}
+			if (rc & ~0x6ffffU) {
+				printf("%s%#lx",
+				       rc & 0x60000 ? "|" : "", rc & ~0x6ffffU);
+			}
+			printf("|%#lx)\n", rc & 0xffffU);
+		} else {
+			puts("");
+		}
+	} else {
+		puts(sprintrc(rc));
 	}
-	puts("");
 
 	puts("+++ exited with 0 +++");
 	return 0;
